OpenAiApiClient class
- Implemented types
Constructors
- OpenAiApiClient({required FluenticConfig config})
Properties
- config → FluenticConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executePrompt(
String userPromptContent, {String? effectiveSystemPrompt}) → Future -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited