FluenticConfig class

Constructors

FluenticConfig({required String apiKey, String model = "gpt-3.5-turbo-1106", String baseUrl = "https://api.openai.com/v1", String? defaultSystemPrompt})

Properties

apiKey String
final
baseUrl String
final
defaultSystemPrompt String?
final
hashCode int
The hash code for this object.
no setterinherited
model String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? apiKey, String? model, String? baseUrl, String? defaultSystemPrompt, bool clearDefaultSystemPrompt = false}) FluenticConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

global FluenticConfig
getter/setter pair